part of gitea_openapi;

class OrganizationApi {
  final ApiClient apiClient;

  OrganizationApi([ApiClient apiClient])
      : apiClient = apiClient ?? defaultApiClient;

  /// Create a repository in an organization with HTTP info returned
  ///
  ///
  Future<Response> createOrgRepoWithHttpInfo(String org,
      {CreateRepoOption body}) async {
    Object postBody = body;

    // verify required params are set
    if (org == null) {
      throw ApiException(400, "Missing required param: org");
    }

    // create path and map variables
    String path = "/orgs/{org}/repos"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "org" + "}", org.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json"];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'POST', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Create a repository in an organization
  ///
  ///
  Future<Repository> createOrgRepo(String org, {CreateRepoOption body}) async {
    Response response = await createOrgRepoWithHttpInfo(org, body: body);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Repository')
          as Repository;
    } else {
      return null;
    }
  }

  /// Create a repository in an organization with HTTP info returned
  ///
  ///
  Future<Response> createOrgRepoDeprecatedWithHttpInfo(String org,
      {CreateRepoOption body}) async {
    Object postBody = body;

    // verify required params are set
    if (org == null) {
      throw ApiException(400, "Missing required param: org");
    }

    // create path and map variables
    String path = "/org/{org}/repos"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "org" + "}", org.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json"];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'POST', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Create a repository in an organization
  ///
  ///
  Future<Repository> createOrgRepoDeprecated(String org,
      {CreateRepoOption body}) async {
    Response response =
        await createOrgRepoDeprecatedWithHttpInfo(org, body: body);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Repository')
          as Repository;
    } else {
      return null;
    }
  }

  /// Add a team member with HTTP info returned
  ///
  ///
  Future orgAddTeamMemberWithHttpInfo(int id, String username) async {
    Object postBody;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, "Missing required param: id");
    }
    if (username == null) {
      throw ApiException(400, "Missing required param: username");
    }

    // create path and map variables
    String path = "/teams/{id}/members/{username}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "id" + "}", id.toString())
        .replaceAll("{" + "username" + "}", username.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'PUT', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Add a team member
  ///
  ///
  Future orgAddTeamMember(int id, String username) async {
    Response response = await orgAddTeamMemberWithHttpInfo(id, username);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
    } else {
      return;
    }
  }

  /// Add a repository to a team with HTTP info returned
  ///
  ///
  Future orgAddTeamRepositoryWithHttpInfo(
      int id, String org, String repo) async {
    Object postBody;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, "Missing required param: id");
    }
    if (org == null) {
      throw ApiException(400, "Missing required param: org");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }

    // create path and map variables
    String path = "/teams/{id}/repos/{org}/{repo}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "id" + "}", id.toString())
        .replaceAll("{" + "org" + "}", org.toString())
        .replaceAll("{" + "repo" + "}", repo.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'PUT', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Add a repository to a team
  ///
  ///
  Future orgAddTeamRepository(int id, String org, String repo) async {
    Response response = await orgAddTeamRepositoryWithHttpInfo(id, org, repo);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
    } else {
      return;
    }
  }

  /// Conceal a user&#39;s membership with HTTP info returned
  ///
  ///
  Future orgConcealMemberWithHttpInfo(String org, String username) async {
    Object postBody;

    // verify required params are set
    if (org == null) {
      throw ApiException(400, "Missing required param: org");
    }
    if (username == null) {
      throw ApiException(400, "Missing required param: username");
    }

    // create path and map variables
    String path = "/orgs/{org}/public_members/{username}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "org" + "}", org.toString())
        .replaceAll("{" + "username" + "}", username.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'DELETE', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Conceal a user&#39;s membership
  ///
  ///
  Future orgConcealMember(String org, String username) async {
    Response response = await orgConcealMemberWithHttpInfo(org, username);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
    } else {
      return;
    }
  }

  /// Create an organization with HTTP info returned
  ///
  ///
  Future<Response> orgCreateWithHttpInfo(CreateOrgOption organization) async {
    Object postBody = organization;

    // verify required params are set
    if (organization == null) {
      throw ApiException(400, "Missing required param: organization");
    }

    // create path and map variables
    String path = "/orgs".replaceAll("{format}", "json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json"];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'POST', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Create an organization
  ///
  ///
  Future<Organization> orgCreate(CreateOrgOption organization) async {
    Response response = await orgCreateWithHttpInfo(organization);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Organization')
          as Organization;
    } else {
      return null;
    }
  }

  /// Create a hook with HTTP info returned
  ///
  ///
  Future<Response> orgCreateHookWithHttpInfo(
      String org, CreateHookOption body) async {
    Object postBody = body;

    // verify required params are set
    if (org == null) {
      throw ApiException(400, "Missing required param: org");
    }
    if (body == null) {
      throw ApiException(400, "Missing required param: body");
    }

    // create path and map variables
    String path = "/orgs/{org}/hooks/"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "org" + "}", org.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json"];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'POST', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Create a hook
  ///
  ///
  Future<Hook> orgCreateHook(String org, CreateHookOption body) async {
    Response response = await orgCreateHookWithHttpInfo(org, body);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Hook') as Hook;
    } else {
      return null;
    }
  }

  /// Create a team with HTTP info returned
  ///
  ///
  Future<Response> orgCreateTeamWithHttpInfo(String org,
      {CreateTeamOption body}) async {
    Object postBody = body;

    // verify required params are set
    if (org == null) {
      throw ApiException(400, "Missing required param: org");
    }

    // create path and map variables
    String path = "/orgs/{org}/teams"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "org" + "}", org.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json"];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'POST', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Create a team
  ///
  ///
  Future<Team> orgCreateTeam(String org, {CreateTeamOption body}) async {
    Response response = await orgCreateTeamWithHttpInfo(org, body: body);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Team') as Team;
    } else {
      return null;
    }
  }

  /// Delete an organization with HTTP info returned
  ///
  ///
  Future orgDeleteWithHttpInfo(String org) async {
    Object postBody;

    // verify required params are set
    if (org == null) {
      throw ApiException(400, "Missing required param: org");
    }

    // create path and map variables
    String path = "/orgs/{org}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "org" + "}", org.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'DELETE', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Delete an organization
  ///
  ///
  Future orgDelete(String org) async {
    Response response = await orgDeleteWithHttpInfo(org);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
    } else {
      return;
    }
  }

  /// Delete a hook with HTTP info returned
  ///
  ///
  Future orgDeleteHookWithHttpInfo(String org, int id) async {
    Object postBody;

    // verify required params are set
    if (org == null) {
      throw ApiException(400, "Missing required param: org");
    }
    if (id == null) {
      throw ApiException(400, "Missing required param: id");
    }

    // create path and map variables
    String path = "/orgs/{org}/hooks/{id}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "org" + "}", org.toString())
        .replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'DELETE', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Delete a hook
  ///
  ///
  Future orgDeleteHook(String org, int id) async {
    Response response = await orgDeleteHookWithHttpInfo(org, id);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
    } else {
      return;
    }
  }

  /// Remove a member from an organization with HTTP info returned
  ///
  ///
  Future orgDeleteMemberWithHttpInfo(String org, String username) async {
    Object postBody;

    // verify required params are set
    if (org == null) {
      throw ApiException(400, "Missing required param: org");
    }
    if (username == null) {
      throw ApiException(400, "Missing required param: username");
    }

    // create path and map variables
    String path = "/orgs/{org}/members/{username}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "org" + "}", org.toString())
        .replaceAll("{" + "username" + "}", username.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'DELETE', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Remove a member from an organization
  ///
  ///
  Future orgDeleteMember(String org, String username) async {
    Response response = await orgDeleteMemberWithHttpInfo(org, username);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
    } else {
      return;
    }
  }

  /// Delete a team with HTTP info returned
  ///
  ///
  Future orgDeleteTeamWithHttpInfo(int id) async {
    Object postBody;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, "Missing required param: id");
    }

    // create path and map variables
    String path = "/teams/{id}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'DELETE', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Delete a team
  ///
  ///
  Future orgDeleteTeam(int id) async {
    Response response = await orgDeleteTeamWithHttpInfo(id);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
    } else {
      return;
    }
  }

  /// Edit an organization with HTTP info returned
  ///
  ///
  Future<Response> orgEditWithHttpInfo(String org, EditOrgOption body) async {
    Object postBody = body;

    // verify required params are set
    if (org == null) {
      throw ApiException(400, "Missing required param: org");
    }
    if (body == null) {
      throw ApiException(400, "Missing required param: body");
    }

    // create path and map variables
    String path = "/orgs/{org}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "org" + "}", org.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json"];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'PATCH', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Edit an organization
  ///
  ///
  Future<Organization> orgEdit(String org, EditOrgOption body) async {
    Response response = await orgEditWithHttpInfo(org, body);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Organization')
          as Organization;
    } else {
      return null;
    }
  }

  /// Update a hook with HTTP info returned
  ///
  ///
  Future<Response> orgEditHookWithHttpInfo(String org, int id,
      {EditHookOption body}) async {
    Object postBody = body;

    // verify required params are set
    if (org == null) {
      throw ApiException(400, "Missing required param: org");
    }
    if (id == null) {
      throw ApiException(400, "Missing required param: id");
    }

    // create path and map variables
    String path = "/orgs/{org}/hooks/{id}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "org" + "}", org.toString())
        .replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json"];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'PATCH', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Update a hook
  ///
  ///
  Future<Hook> orgEditHook(String org, int id, {EditHookOption body}) async {
    Response response = await orgEditHookWithHttpInfo(org, id, body: body);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Hook') as Hook;
    } else {
      return null;
    }
  }

  /// Edit a team with HTTP info returned
  ///
  ///
  Future<Response> orgEditTeamWithHttpInfo(int id,
      {EditTeamOption body}) async {
    Object postBody = body;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, "Missing required param: id");
    }

    // create path and map variables
    String path = "/teams/{id}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json"];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'PATCH', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Edit a team
  ///
  ///
  Future<Team> orgEditTeam(int id, {EditTeamOption body}) async {
    Response response = await orgEditTeamWithHttpInfo(id, body: body);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Team') as Team;
    } else {
      return null;
    }
  }

  /// Get an organization with HTTP info returned
  ///
  ///
  Future<Response> orgGetWithHttpInfo(String org) async {
    Object postBody;

    // verify required params are set
    if (org == null) {
      throw ApiException(400, "Missing required param: org");
    }

    // create path and map variables
    String path = "/orgs/{org}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "org" + "}", org.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Get an organization
  ///
  ///
  Future<Organization> orgGet(String org) async {
    Response response = await orgGetWithHttpInfo(org);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Organization')
          as Organization;
    } else {
      return null;
    }
  }

  /// Get list of organizations with HTTP info returned
  ///
  ///
  Future<Response> orgGetAllWithHttpInfo({int page, int limit}) async {
    Object postBody;

    // verify required params are set

    // create path and map variables
    String path = "/orgs".replaceAll("{format}", "json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    if (page != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "page", page));
    }
    if (limit != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "limit", limit));
    }

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Get list of organizations
  ///
  ///
  Future<List<Organization>> orgGetAll({int page, int limit}) async {
    Response response = await orgGetAllWithHttpInfo(page: page, limit: limit);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return (apiClient.deserialize(
              _decodeBodyBytes(response), 'List<Organization>') as List)
          .map((item) => item as Organization)
          .toList();
    } else {
      return null;
    }
  }

  /// Get a hook with HTTP info returned
  ///
  ///
  Future<Response> orgGetHookWithHttpInfo(String org, int id) async {
    Object postBody;

    // verify required params are set
    if (org == null) {
      throw ApiException(400, "Missing required param: org");
    }
    if (id == null) {
      throw ApiException(400, "Missing required param: id");
    }

    // create path and map variables
    String path = "/orgs/{org}/hooks/{id}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "org" + "}", org.toString())
        .replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Get a hook
  ///
  ///
  Future<Hook> orgGetHook(String org, int id) async {
    Response response = await orgGetHookWithHttpInfo(org, id);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Hook') as Hook;
    } else {
      return null;
    }
  }

  /// Get a team with HTTP info returned
  ///
  ///
  Future<Response> orgGetTeamWithHttpInfo(int id) async {
    Object postBody;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, "Missing required param: id");
    }

    // create path and map variables
    String path = "/teams/{id}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Get a team
  ///
  ///
  Future<Team> orgGetTeam(int id) async {
    Response response = await orgGetTeamWithHttpInfo(id);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Team') as Team;
    } else {
      return null;
    }
  }

  /// Check if a user is a member of an organization with HTTP info returned
  ///
  ///
  Future orgIsMemberWithHttpInfo(String org, String username) async {
    Object postBody;

    // verify required params are set
    if (org == null) {
      throw ApiException(400, "Missing required param: org");
    }
    if (username == null) {
      throw ApiException(400, "Missing required param: username");
    }

    // create path and map variables
    String path = "/orgs/{org}/members/{username}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "org" + "}", org.toString())
        .replaceAll("{" + "username" + "}", username.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Check if a user is a member of an organization
  ///
  ///
  Future orgIsMember(String org, String username) async {
    Response response = await orgIsMemberWithHttpInfo(org, username);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
    } else {
      return;
    }
  }

  /// Check if a user is a public member of an organization with HTTP info returned
  ///
  ///
  Future orgIsPublicMemberWithHttpInfo(String org, String username) async {
    Object postBody;

    // verify required params are set
    if (org == null) {
      throw ApiException(400, "Missing required param: org");
    }
    if (username == null) {
      throw ApiException(400, "Missing required param: username");
    }

    // create path and map variables
    String path = "/orgs/{org}/public_members/{username}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "org" + "}", org.toString())
        .replaceAll("{" + "username" + "}", username.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Check if a user is a public member of an organization
  ///
  ///
  Future orgIsPublicMember(String org, String username) async {
    Response response = await orgIsPublicMemberWithHttpInfo(org, username);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
    } else {
      return;
    }
  }

  /// List the current user&#39;s organizations with HTTP info returned
  ///
  ///
  Future<Response> orgListCurrentUserOrgsWithHttpInfo(
      {int page, int limit}) async {
    Object postBody;

    // verify required params are set

    // create path and map variables
    String path = "/user/orgs".replaceAll("{format}", "json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    if (page != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "page", page));
    }
    if (limit != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "limit", limit));
    }

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// List the current user&#39;s organizations
  ///
  ///
  Future<List<Organization>> orgListCurrentUserOrgs(
      {int page, int limit}) async {
    Response response =
        await orgListCurrentUserOrgsWithHttpInfo(page: page, limit: limit);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return (apiClient.deserialize(
              _decodeBodyBytes(response), 'List<Organization>') as List)
          .map((item) => item as Organization)
          .toList();
    } else {
      return null;
    }
  }

  /// List an organization&#39;s webhooks with HTTP info returned
  ///
  ///
  Future<Response> orgListHooksWithHttpInfo(String org,
      {int page, int limit}) async {
    Object postBody;

    // verify required params are set
    if (org == null) {
      throw ApiException(400, "Missing required param: org");
    }

    // create path and map variables
    String path = "/orgs/{org}/hooks"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "org" + "}", org.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    if (page != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "page", page));
    }
    if (limit != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "limit", limit));
    }

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// List an organization&#39;s webhooks
  ///
  ///
  Future<List<Hook>> orgListHooks(String org, {int page, int limit}) async {
    Response response =
        await orgListHooksWithHttpInfo(org, page: page, limit: limit);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return (apiClient.deserialize(_decodeBodyBytes(response), 'List<Hook>')
              as List)
          .map((item) => item as Hook)
          .toList();
    } else {
      return null;
    }
  }

  /// List an organization&#39;s members with HTTP info returned
  ///
  ///
  Future<Response> orgListMembersWithHttpInfo(String org,
      {int page, int limit}) async {
    Object postBody;

    // verify required params are set
    if (org == null) {
      throw ApiException(400, "Missing required param: org");
    }

    // create path and map variables
    String path = "/orgs/{org}/members"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "org" + "}", org.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    if (page != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "page", page));
    }
    if (limit != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "limit", limit));
    }

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// List an organization&#39;s members
  ///
  ///
  Future<List<User>> orgListMembers(String org, {int page, int limit}) async {
    Response response =
        await orgListMembersWithHttpInfo(org, page: page, limit: limit);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return (apiClient.deserialize(_decodeBodyBytes(response), 'List<User>')
              as List)
          .map((item) => item as User)
          .toList();
    } else {
      return null;
    }
  }

  /// List an organization&#39;s public members with HTTP info returned
  ///
  ///
  Future<Response> orgListPublicMembersWithHttpInfo(String org,
      {int page, int limit}) async {
    Object postBody;

    // verify required params are set
    if (org == null) {
      throw ApiException(400, "Missing required param: org");
    }

    // create path and map variables
    String path = "/orgs/{org}/public_members"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "org" + "}", org.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    if (page != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "page", page));
    }
    if (limit != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "limit", limit));
    }

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// List an organization&#39;s public members
  ///
  ///
  Future<List<User>> orgListPublicMembers(String org,
      {int page, int limit}) async {
    Response response =
        await orgListPublicMembersWithHttpInfo(org, page: page, limit: limit);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return (apiClient.deserialize(_decodeBodyBytes(response), 'List<User>')
              as List)
          .map((item) => item as User)
          .toList();
    } else {
      return null;
    }
  }

  /// List an organization&#39;s repos with HTTP info returned
  ///
  ///
  Future<Response> orgListReposWithHttpInfo(String org,
      {int page, int limit}) async {
    Object postBody;

    // verify required params are set
    if (org == null) {
      throw ApiException(400, "Missing required param: org");
    }

    // create path and map variables
    String path = "/orgs/{org}/repos"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "org" + "}", org.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    if (page != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "page", page));
    }
    if (limit != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "limit", limit));
    }

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// List an organization&#39;s repos
  ///
  ///
  Future<List<Repository>> orgListRepos(String org,
      {int page, int limit}) async {
    Response response =
        await orgListReposWithHttpInfo(org, page: page, limit: limit);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return (apiClient.deserialize(
              _decodeBodyBytes(response), 'List<Repository>') as List)
          .map((item) => item as Repository)
          .toList();
    } else {
      return null;
    }
  }

  /// List a particular member of team with HTTP info returned
  ///
  ///
  Future<Response> orgListTeamMemberWithHttpInfo(
      int id, String username) async {
    Object postBody;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, "Missing required param: id");
    }
    if (username == null) {
      throw ApiException(400, "Missing required param: username");
    }

    // create path and map variables
    String path = "/teams/{id}/members/{username}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "id" + "}", id.toString())
        .replaceAll("{" + "username" + "}", username.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// List a particular member of team
  ///
  ///
  Future<User> orgListTeamMember(int id, String username) async {
    Response response = await orgListTeamMemberWithHttpInfo(id, username);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'User') as User;
    } else {
      return null;
    }
  }

  /// List a team&#39;s members with HTTP info returned
  ///
  ///
  Future<Response> orgListTeamMembersWithHttpInfo(int id,
      {int page, int limit}) async {
    Object postBody;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, "Missing required param: id");
    }

    // create path and map variables
    String path = "/teams/{id}/members"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    if (page != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "page", page));
    }
    if (limit != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "limit", limit));
    }

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// List a team&#39;s members
  ///
  ///
  Future<List<User>> orgListTeamMembers(int id, {int page, int limit}) async {
    Response response =
        await orgListTeamMembersWithHttpInfo(id, page: page, limit: limit);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return (apiClient.deserialize(_decodeBodyBytes(response), 'List<User>')
              as List)
          .map((item) => item as User)
          .toList();
    } else {
      return null;
    }
  }

  /// List a team&#39;s repos with HTTP info returned
  ///
  ///
  Future<Response> orgListTeamReposWithHttpInfo(int id,
      {int page, int limit}) async {
    Object postBody;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, "Missing required param: id");
    }

    // create path and map variables
    String path = "/teams/{id}/repos"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    if (page != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "page", page));
    }
    if (limit != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "limit", limit));
    }

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// List a team&#39;s repos
  ///
  ///
  Future<List<Repository>> orgListTeamRepos(int id,
      {int page, int limit}) async {
    Response response =
        await orgListTeamReposWithHttpInfo(id, page: page, limit: limit);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return (apiClient.deserialize(
              _decodeBodyBytes(response), 'List<Repository>') as List)
          .map((item) => item as Repository)
          .toList();
    } else {
      return null;
    }
  }

  /// List an organization&#39;s teams with HTTP info returned
  ///
  ///
  Future<Response> orgListTeamsWithHttpInfo(String org,
      {int page, int limit}) async {
    Object postBody;

    // verify required params are set
    if (org == null) {
      throw ApiException(400, "Missing required param: org");
    }

    // create path and map variables
    String path = "/orgs/{org}/teams"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "org" + "}", org.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    if (page != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "page", page));
    }
    if (limit != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "limit", limit));
    }

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// List an organization&#39;s teams
  ///
  ///
  Future<List<Team>> orgListTeams(String org, {int page, int limit}) async {
    Response response =
        await orgListTeamsWithHttpInfo(org, page: page, limit: limit);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return (apiClient.deserialize(_decodeBodyBytes(response), 'List<Team>')
              as List)
          .map((item) => item as Team)
          .toList();
    } else {
      return null;
    }
  }

  /// List a user&#39;s organizations with HTTP info returned
  ///
  ///
  Future<Response> orgListUserOrgsWithHttpInfo(String username,
      {int page, int limit}) async {
    Object postBody;

    // verify required params are set
    if (username == null) {
      throw ApiException(400, "Missing required param: username");
    }

    // create path and map variables
    String path = "/users/{username}/orgs"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "username" + "}", username.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    if (page != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "page", page));
    }
    if (limit != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "limit", limit));
    }

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// List a user&#39;s organizations
  ///
  ///
  Future<List<Organization>> orgListUserOrgs(String username,
      {int page, int limit}) async {
    Response response =
        await orgListUserOrgsWithHttpInfo(username, page: page, limit: limit);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return (apiClient.deserialize(
              _decodeBodyBytes(response), 'List<Organization>') as List)
          .map((item) => item as Organization)
          .toList();
    } else {
      return null;
    }
  }

  /// Publicize a user&#39;s membership with HTTP info returned
  ///
  ///
  Future orgPublicizeMemberWithHttpInfo(String org, String username) async {
    Object postBody;

    // verify required params are set
    if (org == null) {
      throw ApiException(400, "Missing required param: org");
    }
    if (username == null) {
      throw ApiException(400, "Missing required param: username");
    }

    // create path and map variables
    String path = "/orgs/{org}/public_members/{username}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "org" + "}", org.toString())
        .replaceAll("{" + "username" + "}", username.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'PUT', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Publicize a user&#39;s membership
  ///
  ///
  Future orgPublicizeMember(String org, String username) async {
    Response response = await orgPublicizeMemberWithHttpInfo(org, username);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
    } else {
      return;
    }
  }

  /// Remove a team member with HTTP info returned
  ///
  ///
  Future orgRemoveTeamMemberWithHttpInfo(int id, String username) async {
    Object postBody;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, "Missing required param: id");
    }
    if (username == null) {
      throw ApiException(400, "Missing required param: username");
    }

    // create path and map variables
    String path = "/teams/{id}/members/{username}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "id" + "}", id.toString())
        .replaceAll("{" + "username" + "}", username.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'DELETE', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Remove a team member
  ///
  ///
  Future orgRemoveTeamMember(int id, String username) async {
    Response response = await orgRemoveTeamMemberWithHttpInfo(id, username);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
    } else {
      return;
    }
  }

  /// Remove a repository from a team with HTTP info returned
  ///
  /// This does not delete the repository, it only removes the repository from the team.
  Future orgRemoveTeamRepositoryWithHttpInfo(
      int id, String org, String repo) async {
    Object postBody;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, "Missing required param: id");
    }
    if (org == null) {
      throw ApiException(400, "Missing required param: org");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }

    // create path and map variables
    String path = "/teams/{id}/repos/{org}/{repo}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "id" + "}", id.toString())
        .replaceAll("{" + "org" + "}", org.toString())
        .replaceAll("{" + "repo" + "}", repo.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'DELETE', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Remove a repository from a team
  ///
  /// This does not delete the repository, it only removes the repository from the team.
  Future orgRemoveTeamRepository(int id, String org, String repo) async {
    Response response =
        await orgRemoveTeamRepositoryWithHttpInfo(id, org, repo);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
    } else {
      return;
    }
  }

  /// Search for teams within an organization with HTTP info returned
  ///
  ///
  Future<Response> teamSearchWithHttpInfo(String org,
      {String q, bool includeDesc, int page, int limit}) async {
    Object postBody;

    // verify required params are set
    if (org == null) {
      throw ApiException(400, "Missing required param: org");
    }

    // create path and map variables
    String path = "/orgs/{org}/teams/search"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "org" + "}", org.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    if (q != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "q", q));
    }
    if (includeDesc != null) {
      queryParams.addAll(_convertParametersForCollectionFormat(
          "", "include_desc", includeDesc));
    }
    if (page != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "page", page));
    }
    if (limit != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "limit", limit));
    }

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Search for teams within an organization
  ///
  ///
  Future<InlineResponse200> teamSearch(String org,
      {String q, bool includeDesc, int page, int limit}) async {
    Response response = await teamSearchWithHttpInfo(org,
        q: q, includeDesc: includeDesc, page: page, limit: limit);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(
          _decodeBodyBytes(response), 'InlineResponse200') as InlineResponse200;
    } else {
      return null;
    }
  }
}
