part of gitea_openapi;

class RepositoryApi {
  final ApiClient apiClient;

  RepositoryApi([ApiClient apiClient])
      : apiClient = apiClient ?? defaultApiClient;

  /// Create a repository with HTTP info returned
  ///
  ///
  Future<Response> createCurrentUserRepoWithHttpInfo(
      {CreateRepoOption body}) async {
    Object postBody = body;

    // verify required params are set

    // create path and map variables
    String path = "/user/repos".replaceAll("{format}", "json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json"];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'POST', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Create a repository
  ///
  ///
  Future<Repository> createCurrentUserRepo({CreateRepoOption body}) async {
    Response response = await createCurrentUserRepoWithHttpInfo(body: body);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Repository')
          as Repository;
    } else {
      return null;
    }
  }

  /// Fork a repository with HTTP info returned
  ///
  ///
  Future<Response> createForkWithHttpInfo(String owner, String repo,
      {CreateForkOption body}) async {
    Object postBody = body;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/forks"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json", "text/plain"];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'POST', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Fork a repository
  ///
  ///
  Future<Repository> createFork(String owner, String repo,
      {CreateForkOption body}) async {
    Response response = await createForkWithHttpInfo(owner, repo, body: body);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Repository')
          as Repository;
    } else {
      return null;
    }
  }

  /// Gets the blob of a repository. with HTTP info returned
  ///
  ///
  Future<Response> getBlobWithHttpInfo(
      String owner, String repo, String sha) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (sha == null) {
      throw ApiException(400, "Missing required param: sha");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/git/blobs/{sha}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "sha" + "}", sha.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Gets the blob of a repository.
  ///
  ///
  Future<GitBlobResponse> getBlob(String owner, String repo, String sha) async {
    Response response = await getBlobWithHttpInfo(owner, repo, sha);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(
          _decodeBodyBytes(response), 'GitBlobResponse') as GitBlobResponse;
    } else {
      return null;
    }
  }

  /// Gets the tag object of an annotated tag (not lightweight tags) with HTTP info returned
  ///
  ///
  Future<Response> getTagWithHttpInfo(
      String owner, String repo, String sha) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (sha == null) {
      throw ApiException(400, "Missing required param: sha");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/git/tags/{sha}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "sha" + "}", sha.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Gets the tag object of an annotated tag (not lightweight tags)
  ///
  ///
  Future<AnnotatedTag> getTag(String owner, String repo, String sha) async {
    Response response = await getTagWithHttpInfo(owner, repo, sha);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'AnnotatedTag')
          as AnnotatedTag;
    } else {
      return null;
    }
  }

  /// Gets the tree of a repository. with HTTP info returned
  ///
  ///
  Future<Response> getTreeWithHttpInfo(String owner, String repo, String sha,
      {bool recursive, int page, int perPage}) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (sha == null) {
      throw ApiException(400, "Missing required param: sha");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/git/trees/{sha}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "sha" + "}", sha.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    if (recursive != null) {
      queryParams.addAll(
          _convertParametersForCollectionFormat("", "recursive", recursive));
    }
    if (page != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "page", page));
    }
    if (perPage != null) {
      queryParams.addAll(
          _convertParametersForCollectionFormat("", "per_page", perPage));
    }

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Gets the tree of a repository.
  ///
  ///
  Future<GitTreeResponse> getTree(String owner, String repo, String sha,
      {bool recursive, int page, int perPage}) async {
    Response response = await getTreeWithHttpInfo(owner, repo, sha,
        recursive: recursive, page: page, perPage: perPage);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(
          _decodeBodyBytes(response), 'GitTreeResponse') as GitTreeResponse;
    } else {
      return null;
    }
  }

  /// List a repository&#39;s forks with HTTP info returned
  ///
  ///
  Future<Response> listForksWithHttpInfo(String owner, String repo,
      {int page, int limit}) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/forks"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    if (page != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "page", page));
    }
    if (limit != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "limit", limit));
    }

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// List a repository&#39;s forks
  ///
  ///
  Future<List<Repository>> listForks(String owner, String repo,
      {int page, int limit}) async {
    Response response =
        await listForksWithHttpInfo(owner, repo, page: page, limit: limit);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return (apiClient.deserialize(
              _decodeBodyBytes(response), 'List<Repository>') as List)
          .map((item) => item as Repository)
          .toList();
    } else {
      return null;
    }
  }

  /// Add a collaborator to a repository with HTTP info returned
  ///
  ///
  Future repoAddCollaboratorWithHttpInfo(
      String owner, String repo, String collaborator,
      {AddCollaboratorOption body}) async {
    Object postBody = body;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (collaborator == null) {
      throw ApiException(400, "Missing required param: collaborator");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/collaborators/{collaborator}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "collaborator" + "}", collaborator.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json", "text/plain"];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'PUT', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Add a collaborator to a repository
  ///
  ///
  Future repoAddCollaborator(String owner, String repo, String collaborator,
      {AddCollaboratorOption body}) async {
    Response response = await repoAddCollaboratorWithHttpInfo(
        owner, repo, collaborator,
        body: body);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
    } else {
      return;
    }
  }

  /// Add a topic to a repository with HTTP info returned
  ///
  ///
  Future repoAddTopicWithHttpInfo(
      String owner, String repo, String topic) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (topic == null) {
      throw ApiException(400, "Missing required param: topic");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/topics/{topic}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "topic" + "}", topic.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'PUT', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Add a topic to a repository
  ///
  ///
  Future repoAddTopic(String owner, String repo, String topic) async {
    Response response = await repoAddTopicWithHttpInfo(owner, repo, topic);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
    } else {
      return;
    }
  }

  /// Check if a user is a collaborator of a repository with HTTP info returned
  ///
  ///
  Future repoCheckCollaboratorWithHttpInfo(
      String owner, String repo, String collaborator) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (collaborator == null) {
      throw ApiException(400, "Missing required param: collaborator");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/collaborators/{collaborator}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "collaborator" + "}", collaborator.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Check if a user is a collaborator of a repository
  ///
  ///
  Future repoCheckCollaborator(
      String owner, String repo, String collaborator) async {
    Response response =
        await repoCheckCollaboratorWithHttpInfo(owner, repo, collaborator);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
    } else {
      return;
    }
  }

  /// Create a branch protections for a repository with HTTP info returned
  ///
  ///
  Future<Response> repoCreateBranchProtectionWithHttpInfo(
      String owner, String repo,
      {CreateBranchProtectionOption body}) async {
    Object postBody = body;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/branch_protections"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json"];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'POST', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Create a branch protections for a repository
  ///
  ///
  Future<BranchProtection> repoCreateBranchProtection(String owner, String repo,
      {CreateBranchProtectionOption body}) async {
    Response response =
        await repoCreateBranchProtectionWithHttpInfo(owner, repo, body: body);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(
          _decodeBodyBytes(response), 'BranchProtection') as BranchProtection;
    } else {
      return null;
    }
  }

  /// Create a file in a repository with HTTP info returned
  ///
  ///
  Future<Response> repoCreateFileWithHttpInfo(String owner, String repo,
      String filepath, CreateFileOptions body) async {
    Object postBody = body;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (filepath == null) {
      throw ApiException(400, "Missing required param: filepath");
    }
    if (body == null) {
      throw ApiException(400, "Missing required param: body");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/contents/{filepath}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "filepath" + "}", filepath.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json"];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'POST', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Create a file in a repository
  ///
  ///
  Future<FileResponse> repoCreateFile(String owner, String repo,
      String filepath, CreateFileOptions body) async {
    Response response =
        await repoCreateFileWithHttpInfo(owner, repo, filepath, body);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'FileResponse')
          as FileResponse;
    } else {
      return null;
    }
  }

  /// Create a hook with HTTP info returned
  ///
  ///
  Future<Response> repoCreateHookWithHttpInfo(String owner, String repo,
      {CreateHookOption body}) async {
    Object postBody = body;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/hooks"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json"];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'POST', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Create a hook
  ///
  ///
  Future<Hook> repoCreateHook(String owner, String repo,
      {CreateHookOption body}) async {
    Response response =
        await repoCreateHookWithHttpInfo(owner, repo, body: body);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Hook') as Hook;
    } else {
      return null;
    }
  }

  /// Add a key to a repository with HTTP info returned
  ///
  ///
  Future<Response> repoCreateKeyWithHttpInfo(String owner, String repo,
      {CreateKeyOption body}) async {
    Object postBody = body;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/keys"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json"];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'POST', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Add a key to a repository
  ///
  ///
  Future<DeployKey> repoCreateKey(String owner, String repo,
      {CreateKeyOption body}) async {
    Response response =
        await repoCreateKeyWithHttpInfo(owner, repo, body: body);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'DeployKey')
          as DeployKey;
    } else {
      return null;
    }
  }

  /// Create a pull request with HTTP info returned
  ///
  ///
  Future<Response> repoCreatePullRequestWithHttpInfo(String owner, String repo,
      {CreatePullRequestOption body}) async {
    Object postBody = body;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/pulls"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json"];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'POST', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Create a pull request
  ///
  ///
  Future<PullRequest> repoCreatePullRequest(String owner, String repo,
      {CreatePullRequestOption body}) async {
    Response response =
        await repoCreatePullRequestWithHttpInfo(owner, repo, body: body);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'PullRequest')
          as PullRequest;
    } else {
      return null;
    }
  }

  /// Create a release with HTTP info returned
  ///
  ///
  Future<Response> repoCreateReleaseWithHttpInfo(String owner, String repo,
      {CreateReleaseOption body}) async {
    Object postBody = body;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/releases"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json"];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'POST', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Create a release
  ///
  ///
  Future<Release> repoCreateRelease(String owner, String repo,
      {CreateReleaseOption body}) async {
    Response response =
        await repoCreateReleaseWithHttpInfo(owner, repo, body: body);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Release')
          as Release;
    } else {
      return null;
    }
  }

  /// Create a release attachment with HTTP info returned
  ///
  ///
  Future<Response> repoCreateReleaseAttachmentWithHttpInfo(
      String owner, String repo, int id, MultipartFile attachment,
      {String name}) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (id == null) {
      throw ApiException(400, "Missing required param: id");
    }
    if (attachment == null) {
      throw ApiException(400, "Missing required param: attachment");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/releases/{id}/assets"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    if (name != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "name", name));
    }

    List<String> contentTypes = ["multipart/form-data"];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (attachment != null) {
        hasFields = true;
        mp.fields['attachment'] = attachment.field;
        mp.files.add(attachment);
      }
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'POST', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Create a release attachment
  ///
  ///
  Future<Attachment> repoCreateReleaseAttachment(
      String owner, String repo, int id, MultipartFile attachment,
      {String name}) async {
    Response response = await repoCreateReleaseAttachmentWithHttpInfo(
        owner, repo, id, attachment,
        name: name);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Attachment')
          as Attachment;
    } else {
      return null;
    }
  }

  /// Create a commit status with HTTP info returned
  ///
  ///
  Future<Response> repoCreateStatusWithHttpInfo(
      String owner, String repo, String sha,
      {CreateStatusOption body}) async {
    Object postBody = body;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (sha == null) {
      throw ApiException(400, "Missing required param: sha");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/statuses/{sha}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "sha" + "}", sha.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json", "text/plain"];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'POST', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Create a commit status
  ///
  ///
  Future<Status> repoCreateStatus(String owner, String repo, String sha,
      {CreateStatusOption body}) async {
    Response response =
        await repoCreateStatusWithHttpInfo(owner, repo, sha, body: body);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Status')
          as Status;
    } else {
      return null;
    }
  }

  /// Delete a repository with HTTP info returned
  ///
  ///
  Future repoDeleteWithHttpInfo(String owner, String repo) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'DELETE', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Delete a repository
  ///
  ///
  Future repoDelete(String owner, String repo) async {
    Response response = await repoDeleteWithHttpInfo(owner, repo);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
    } else {
      return;
    }
  }

  /// Delete a specific branch protection for the repository with HTTP info returned
  ///
  ///
  Future repoDeleteBranchProtectionWithHttpInfo(
      String owner, String repo, String name) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (name == null) {
      throw ApiException(400, "Missing required param: name");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/branch_protections/{name}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "name" + "}", name.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'DELETE', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Delete a specific branch protection for the repository
  ///
  ///
  Future repoDeleteBranchProtection(
      String owner, String repo, String name) async {
    Response response =
        await repoDeleteBranchProtectionWithHttpInfo(owner, repo, name);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
    } else {
      return;
    }
  }

  /// Delete a collaborator from a repository with HTTP info returned
  ///
  ///
  Future repoDeleteCollaboratorWithHttpInfo(
      String owner, String repo, String collaborator) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (collaborator == null) {
      throw ApiException(400, "Missing required param: collaborator");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/collaborators/{collaborator}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "collaborator" + "}", collaborator.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'DELETE', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Delete a collaborator from a repository
  ///
  ///
  Future repoDeleteCollaborator(
      String owner, String repo, String collaborator) async {
    Response response =
        await repoDeleteCollaboratorWithHttpInfo(owner, repo, collaborator);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
    } else {
      return;
    }
  }

  /// Delete a file in a repository with HTTP info returned
  ///
  ///
  Future<Response> repoDeleteFileWithHttpInfo(String owner, String repo,
      String filepath, DeleteFileOptions body) async {
    Object postBody = body;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (filepath == null) {
      throw ApiException(400, "Missing required param: filepath");
    }
    if (body == null) {
      throw ApiException(400, "Missing required param: body");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/contents/{filepath}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "filepath" + "}", filepath.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json"];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'DELETE', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Delete a file in a repository
  ///
  ///
  Future<FileDeleteResponse> repoDeleteFile(String owner, String repo,
      String filepath, DeleteFileOptions body) async {
    Response response =
        await repoDeleteFileWithHttpInfo(owner, repo, filepath, body);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(
              _decodeBodyBytes(response), 'FileDeleteResponse')
          as FileDeleteResponse;
    } else {
      return null;
    }
  }

  /// Delete a Git hook in a repository with HTTP info returned
  ///
  ///
  Future repoDeleteGitHookWithHttpInfo(
      String owner, String repo, String id) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (id == null) {
      throw ApiException(400, "Missing required param: id");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/hooks/git/{id}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'DELETE', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Delete a Git hook in a repository
  ///
  ///
  Future repoDeleteGitHook(String owner, String repo, String id) async {
    Response response = await repoDeleteGitHookWithHttpInfo(owner, repo, id);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
    } else {
      return;
    }
  }

  /// Delete a hook in a repository with HTTP info returned
  ///
  ///
  Future repoDeleteHookWithHttpInfo(String owner, String repo, int id) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (id == null) {
      throw ApiException(400, "Missing required param: id");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/hooks/{id}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'DELETE', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Delete a hook in a repository
  ///
  ///
  Future repoDeleteHook(String owner, String repo, int id) async {
    Response response = await repoDeleteHookWithHttpInfo(owner, repo, id);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
    } else {
      return;
    }
  }

  /// Delete a key from a repository with HTTP info returned
  ///
  ///
  Future repoDeleteKeyWithHttpInfo(String owner, String repo, int id) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (id == null) {
      throw ApiException(400, "Missing required param: id");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/keys/{id}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'DELETE', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Delete a key from a repository
  ///
  ///
  Future repoDeleteKey(String owner, String repo, int id) async {
    Response response = await repoDeleteKeyWithHttpInfo(owner, repo, id);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
    } else {
      return;
    }
  }

  /// Delete a release with HTTP info returned
  ///
  ///
  Future repoDeleteReleaseWithHttpInfo(
      String owner, String repo, int id) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (id == null) {
      throw ApiException(400, "Missing required param: id");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/releases/{id}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'DELETE', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Delete a release
  ///
  ///
  Future repoDeleteRelease(String owner, String repo, int id) async {
    Response response = await repoDeleteReleaseWithHttpInfo(owner, repo, id);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
    } else {
      return;
    }
  }

  /// Delete a release attachment with HTTP info returned
  ///
  ///
  Future repoDeleteReleaseAttachmentWithHttpInfo(
      String owner, String repo, int id, int attachmentId) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (id == null) {
      throw ApiException(400, "Missing required param: id");
    }
    if (attachmentId == null) {
      throw ApiException(400, "Missing required param: attachmentId");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/releases/{id}/assets/{attachment_id}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "id" + "}", id.toString())
        .replaceAll("{" + "attachment_id" + "}", attachmentId.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'DELETE', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Delete a release attachment
  ///
  ///
  Future repoDeleteReleaseAttachment(
      String owner, String repo, int id, int attachmentId) async {
    Response response = await repoDeleteReleaseAttachmentWithHttpInfo(
        owner, repo, id, attachmentId);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
    } else {
      return;
    }
  }

  /// Delete a topic from a repository with HTTP info returned
  ///
  ///
  Future repoDeleteTopicWithHttpInfo(
      String owner, String repo, String topic) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (topic == null) {
      throw ApiException(400, "Missing required param: topic");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/topics/{topic}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "topic" + "}", topic.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'DELETE', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Delete a topic from a repository
  ///
  ///
  Future repoDeleteTopic(String owner, String repo, String topic) async {
    Response response = await repoDeleteTopicWithHttpInfo(owner, repo, topic);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
    } else {
      return;
    }
  }

  /// Edit a repository&#39;s properties. Only fields that are set will be changed. with HTTP info returned
  ///
  ///
  Future<Response> repoEditWithHttpInfo(String owner, String repo,
      {EditRepoOption body}) async {
    Object postBody = body;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json", "text/plain"];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'PATCH', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Edit a repository&#39;s properties. Only fields that are set will be changed.
  ///
  ///
  Future<Repository> repoEdit(String owner, String repo,
      {EditRepoOption body}) async {
    Response response = await repoEditWithHttpInfo(owner, repo, body: body);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Repository')
          as Repository;
    } else {
      return null;
    }
  }

  /// Edit a branch protections for a repository. Only fields that are set will be changed with HTTP info returned
  ///
  ///
  Future<Response> repoEditBranchProtectionWithHttpInfo(
      String owner, String repo, String name,
      {EditBranchProtectionOption body}) async {
    Object postBody = body;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (name == null) {
      throw ApiException(400, "Missing required param: name");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/branch_protections/{name}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "name" + "}", name.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json"];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'PATCH', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Edit a branch protections for a repository. Only fields that are set will be changed
  ///
  ///
  Future<BranchProtection> repoEditBranchProtection(
      String owner, String repo, String name,
      {EditBranchProtectionOption body}) async {
    Response response = await repoEditBranchProtectionWithHttpInfo(
        owner, repo, name,
        body: body);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(
          _decodeBodyBytes(response), 'BranchProtection') as BranchProtection;
    } else {
      return null;
    }
  }

  /// Edit a Git hook in a repository with HTTP info returned
  ///
  ///
  Future<Response> repoEditGitHookWithHttpInfo(
      String owner, String repo, String id,
      {EditGitHookOption body}) async {
    Object postBody = body;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (id == null) {
      throw ApiException(400, "Missing required param: id");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/hooks/git/{id}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json", "text/plain"];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'PATCH', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Edit a Git hook in a repository
  ///
  ///
  Future<GitHook> repoEditGitHook(String owner, String repo, String id,
      {EditGitHookOption body}) async {
    Response response =
        await repoEditGitHookWithHttpInfo(owner, repo, id, body: body);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'GitHook')
          as GitHook;
    } else {
      return null;
    }
  }

  /// Edit a hook in a repository with HTTP info returned
  ///
  ///
  Future<Response> repoEditHookWithHttpInfo(String owner, String repo, int id,
      {EditHookOption body}) async {
    Object postBody = body;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (id == null) {
      throw ApiException(400, "Missing required param: id");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/hooks/{id}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json", "text/plain"];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'PATCH', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Edit a hook in a repository
  ///
  ///
  Future<Hook> repoEditHook(String owner, String repo, int id,
      {EditHookOption body}) async {
    Response response =
        await repoEditHookWithHttpInfo(owner, repo, id, body: body);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Hook') as Hook;
    } else {
      return null;
    }
  }

  /// Update a pull request. If using deadline only the date will be taken into account, and time of day ignored. with HTTP info returned
  ///
  ///
  Future<Response> repoEditPullRequestWithHttpInfo(
      String owner, String repo, int index,
      {EditPullRequestOption body}) async {
    Object postBody = body;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (index == null) {
      throw ApiException(400, "Missing required param: index");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/pulls/{index}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "index" + "}", index.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json"];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'PATCH', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Update a pull request. If using deadline only the date will be taken into account, and time of day ignored.
  ///
  ///
  Future<PullRequest> repoEditPullRequest(String owner, String repo, int index,
      {EditPullRequestOption body}) async {
    Response response =
        await repoEditPullRequestWithHttpInfo(owner, repo, index, body: body);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'PullRequest')
          as PullRequest;
    } else {
      return null;
    }
  }

  /// Update a release with HTTP info returned
  ///
  ///
  Future<Response> repoEditReleaseWithHttpInfo(
      String owner, String repo, int id,
      {EditReleaseOption body}) async {
    Object postBody = body;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (id == null) {
      throw ApiException(400, "Missing required param: id");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/releases/{id}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json"];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'PATCH', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Update a release
  ///
  ///
  Future<Release> repoEditRelease(String owner, String repo, int id,
      {EditReleaseOption body}) async {
    Response response =
        await repoEditReleaseWithHttpInfo(owner, repo, id, body: body);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Release')
          as Release;
    } else {
      return null;
    }
  }

  /// Edit a release attachment with HTTP info returned
  ///
  ///
  Future<Response> repoEditReleaseAttachmentWithHttpInfo(
      String owner, String repo, int id, int attachmentId,
      {EditAttachmentOptions body}) async {
    Object postBody = body;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (id == null) {
      throw ApiException(400, "Missing required param: id");
    }
    if (attachmentId == null) {
      throw ApiException(400, "Missing required param: attachmentId");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/releases/{id}/assets/{attachment_id}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "id" + "}", id.toString())
        .replaceAll("{" + "attachment_id" + "}", attachmentId.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json"];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'PATCH', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Edit a release attachment
  ///
  ///
  Future<Attachment> repoEditReleaseAttachment(
      String owner, String repo, int id, int attachmentId,
      {EditAttachmentOptions body}) async {
    Response response = await repoEditReleaseAttachmentWithHttpInfo(
        owner, repo, id, attachmentId,
        body: body);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Attachment')
          as Attachment;
    } else {
      return null;
    }
  }

  /// Get a repository with HTTP info returned
  ///
  ///
  Future<Response> repoGetWithHttpInfo(String owner, String repo) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Get a repository
  ///
  ///
  Future<Repository> repoGet(String owner, String repo) async {
    Response response = await repoGetWithHttpInfo(owner, repo);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Repository')
          as Repository;
    } else {
      return null;
    }
  }

  /// Get a list of all commits from a repository with HTTP info returned
  ///
  ///
  Future<Response> repoGetAllCommitsWithHttpInfo(String owner, String repo,
      {String sha, int page, int limit}) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/commits"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    if (sha != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "sha", sha));
    }
    if (page != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "page", page));
    }
    if (limit != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "limit", limit));
    }

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Get a list of all commits from a repository
  ///
  ///
  Future<List<Commit>> repoGetAllCommits(String owner, String repo,
      {String sha, int page, int limit}) async {
    Response response = await repoGetAllCommitsWithHttpInfo(owner, repo,
        sha: sha, page: page, limit: limit);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return (apiClient.deserialize(_decodeBodyBytes(response), 'List<Commit>')
              as List)
          .map((item) => item as Commit)
          .toList();
    } else {
      return null;
    }
  }

  /// Get an archive of a repository with HTTP info returned
  ///
  ///
  Future repoGetArchiveWithHttpInfo(
      String owner, String repo, String archive) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (archive == null) {
      throw ApiException(400, "Missing required param: archive");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/archive/{archive}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "archive" + "}", archive.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Get an archive of a repository
  ///
  ///
  Future repoGetArchive(String owner, String repo, String archive) async {
    Response response = await repoGetArchiveWithHttpInfo(owner, repo, archive);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
    } else {
      return;
    }
  }

  /// Retrieve a specific branch from a repository, including its effective branch protection with HTTP info returned
  ///
  ///
  Future<Response> repoGetBranchWithHttpInfo(
      String owner, String repo, String branch) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (branch == null) {
      throw ApiException(400, "Missing required param: branch");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/branches/{branch}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "branch" + "}", branch.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Retrieve a specific branch from a repository, including its effective branch protection
  ///
  ///
  Future<Branch> repoGetBranch(String owner, String repo, String branch) async {
    Response response = await repoGetBranchWithHttpInfo(owner, repo, branch);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Branch')
          as Branch;
    } else {
      return null;
    }
  }

  /// Get a specific branch protection for the repository with HTTP info returned
  ///
  ///
  Future<Response> repoGetBranchProtectionWithHttpInfo(
      String owner, String repo, String name) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (name == null) {
      throw ApiException(400, "Missing required param: name");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/branch_protections/{name}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "name" + "}", name.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Get a specific branch protection for the repository
  ///
  ///
  Future<BranchProtection> repoGetBranchProtection(
      String owner, String repo, String name) async {
    Response response =
        await repoGetBranchProtectionWithHttpInfo(owner, repo, name);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(
          _decodeBodyBytes(response), 'BranchProtection') as BranchProtection;
    } else {
      return null;
    }
  }

  /// Get a repository by id with HTTP info returned
  ///
  ///
  Future<Response> repoGetByIDWithHttpInfo(int id) async {
    Object postBody;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, "Missing required param: id");
    }

    // create path and map variables
    String path = "/repositories/{id}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Get a repository by id
  ///
  ///
  Future<Repository> repoGetByID(int id) async {
    Response response = await repoGetByIDWithHttpInfo(id);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Repository')
          as Repository;
    } else {
      return null;
    }
  }

  /// Get a commit&#39;s combined status, by branch/tag/commit reference with HTTP info returned
  ///
  ///
  Future<Response> repoGetCombinedStatusByRefWithHttpInfo(
      String owner, String repo, String ref,
      {int page}) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (ref == null) {
      throw ApiException(400, "Missing required param: ref");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/commits/{ref}/statuses"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "ref" + "}", ref.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    if (page != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "page", page));
    }

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Get a commit&#39;s combined status, by branch/tag/commit reference
  ///
  ///
  Future<Status> repoGetCombinedStatusByRef(
      String owner, String repo, String ref,
      {int page}) async {
    Response response = await repoGetCombinedStatusByRefWithHttpInfo(
        owner, repo, ref,
        page: page);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Status')
          as Status;
    } else {
      return null;
    }
  }

  /// Gets the metadata and contents (if a file) of an entry in a repository, or a list of entries if a dir with HTTP info returned
  ///
  ///
  Future<Response> repoGetContentsWithHttpInfo(
      String owner, String repo, String filepath,
      {String ref}) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (filepath == null) {
      throw ApiException(400, "Missing required param: filepath");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/contents/{filepath}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "filepath" + "}", filepath.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    if (ref != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "ref", ref));
    }

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Gets the metadata and contents (if a file) of an entry in a repository, or a list of entries if a dir
  ///
  ///
  Future<ContentsResponse> repoGetContents(
      String owner, String repo, String filepath,
      {String ref}) async {
    Response response =
        await repoGetContentsWithHttpInfo(owner, repo, filepath, ref: ref);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(
          _decodeBodyBytes(response), 'ContentsResponse') as ContentsResponse;
    } else {
      return null;
    }
  }

  /// Gets the metadata of all the entries of the root dir with HTTP info returned
  ///
  ///
  Future<Response> repoGetContentsListWithHttpInfo(String owner, String repo,
      {String ref}) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/contents"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    if (ref != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "ref", ref));
    }

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Gets the metadata of all the entries of the root dir
  ///
  ///
  Future<List<ContentsResponse>> repoGetContentsList(String owner, String repo,
      {String ref}) async {
    Response response =
        await repoGetContentsListWithHttpInfo(owner, repo, ref: ref);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return (apiClient.deserialize(
              _decodeBodyBytes(response), 'List<ContentsResponse>') as List)
          .map((item) => item as ContentsResponse)
          .toList();
    } else {
      return null;
    }
  }

  /// Get the EditorConfig definitions of a file in a repository with HTTP info returned
  ///
  ///
  Future repoGetEditorConfigWithHttpInfo(
      String owner, String repo, String filepath) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (filepath == null) {
      throw ApiException(400, "Missing required param: filepath");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/editorconfig/{filepath}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "filepath" + "}", filepath.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Get the EditorConfig definitions of a file in a repository
  ///
  ///
  Future repoGetEditorConfig(String owner, String repo, String filepath) async {
    Response response =
        await repoGetEditorConfigWithHttpInfo(owner, repo, filepath);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
    } else {
      return;
    }
  }

  /// Get a Git hook with HTTP info returned
  ///
  ///
  Future<Response> repoGetGitHookWithHttpInfo(
      String owner, String repo, String id) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (id == null) {
      throw ApiException(400, "Missing required param: id");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/hooks/git/{id}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Get a Git hook
  ///
  ///
  Future<GitHook> repoGetGitHook(String owner, String repo, String id) async {
    Response response = await repoGetGitHookWithHttpInfo(owner, repo, id);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'GitHook')
          as GitHook;
    } else {
      return null;
    }
  }

  /// Get a hook with HTTP info returned
  ///
  ///
  Future<Response> repoGetHookWithHttpInfo(
      String owner, String repo, int id) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (id == null) {
      throw ApiException(400, "Missing required param: id");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/hooks/{id}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Get a hook
  ///
  ///
  Future<Hook> repoGetHook(String owner, String repo, int id) async {
    Response response = await repoGetHookWithHttpInfo(owner, repo, id);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Hook') as Hook;
    } else {
      return null;
    }
  }

  /// Get a repository&#39;s key by id with HTTP info returned
  ///
  ///
  Future<Response> repoGetKeyWithHttpInfo(
      String owner, String repo, int id) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (id == null) {
      throw ApiException(400, "Missing required param: id");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/keys/{id}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Get a repository&#39;s key by id
  ///
  ///
  Future<DeployKey> repoGetKey(String owner, String repo, int id) async {
    Response response = await repoGetKeyWithHttpInfo(owner, repo, id);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'DeployKey')
          as DeployKey;
    } else {
      return null;
    }
  }

  /// Get a pull request with HTTP info returned
  ///
  ///
  Future<Response> repoGetPullRequestWithHttpInfo(
      String owner, String repo, int index) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (index == null) {
      throw ApiException(400, "Missing required param: index");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/pulls/{index}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "index" + "}", index.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Get a pull request
  ///
  ///
  Future<PullRequest> repoGetPullRequest(
      String owner, String repo, int index) async {
    Response response =
        await repoGetPullRequestWithHttpInfo(owner, repo, index);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'PullRequest')
          as PullRequest;
    } else {
      return null;
    }
  }

  /// Get a file from a repository with HTTP info returned
  ///
  ///
  Future repoGetRawFileWithHttpInfo(
      String owner, String repo, String filepath) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (filepath == null) {
      throw ApiException(400, "Missing required param: filepath");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/raw/{filepath}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "filepath" + "}", filepath.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Get a file from a repository
  ///
  ///
  Future repoGetRawFile(String owner, String repo, String filepath) async {
    Response response = await repoGetRawFileWithHttpInfo(owner, repo, filepath);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
    } else {
      return;
    }
  }

  /// Get a release with HTTP info returned
  ///
  ///
  Future<Response> repoGetReleaseWithHttpInfo(
      String owner, String repo, int id) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (id == null) {
      throw ApiException(400, "Missing required param: id");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/releases/{id}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Get a release
  ///
  ///
  Future<Release> repoGetRelease(String owner, String repo, int id) async {
    Response response = await repoGetReleaseWithHttpInfo(owner, repo, id);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Release')
          as Release;
    } else {
      return null;
    }
  }

  /// Get a release attachment with HTTP info returned
  ///
  ///
  Future<Response> repoGetReleaseAttachmentWithHttpInfo(
      String owner, String repo, int id, int attachmentId) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (id == null) {
      throw ApiException(400, "Missing required param: id");
    }
    if (attachmentId == null) {
      throw ApiException(400, "Missing required param: attachmentId");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/releases/{id}/assets/{attachment_id}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "id" + "}", id.toString())
        .replaceAll("{" + "attachment_id" + "}", attachmentId.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Get a release attachment
  ///
  ///
  Future<Attachment> repoGetReleaseAttachment(
      String owner, String repo, int id, int attachmentId) async {
    Response response = await repoGetReleaseAttachmentWithHttpInfo(
        owner, repo, id, attachmentId);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Attachment')
          as Attachment;
    } else {
      return null;
    }
  }

  /// Get a single commit from a repository with HTTP info returned
  ///
  ///
  Future<Response> repoGetSingleCommitWithHttpInfo(
      String owner, String repo, String sha) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (sha == null) {
      throw ApiException(400, "Missing required param: sha");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/git/commits/{sha}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "sha" + "}", sha.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Get a single commit from a repository
  ///
  ///
  Future<Commit> repoGetSingleCommit(
      String owner, String repo, String sha) async {
    Response response = await repoGetSingleCommitWithHttpInfo(owner, repo, sha);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Commit')
          as Commit;
    } else {
      return null;
    }
  }

  /// Get specified ref or filtered repository&#39;s refs with HTTP info returned
  ///
  ///
  Future<Response> repoListAllGitRefsWithHttpInfo(
      String owner, String repo) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/git/refs"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Get specified ref or filtered repository&#39;s refs
  ///
  ///
  Future<List<Reference>> repoListAllGitRefs(String owner, String repo) async {
    Response response = await repoListAllGitRefsWithHttpInfo(owner, repo);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return (apiClient.deserialize(
              _decodeBodyBytes(response), 'List<Reference>') as List)
          .map((item) => item as Reference)
          .toList();
    } else {
      return null;
    }
  }

  /// List branch protections for a repository with HTTP info returned
  ///
  ///
  Future<Response> repoListBranchProtectionWithHttpInfo(
      String owner, String repo) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/branch_protections"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// List branch protections for a repository
  ///
  ///
  Future<List<BranchProtection>> repoListBranchProtection(
      String owner, String repo) async {
    Response response = await repoListBranchProtectionWithHttpInfo(owner, repo);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return (apiClient.deserialize(
              _decodeBodyBytes(response), 'List<BranchProtection>') as List)
          .map((item) => item as BranchProtection)
          .toList();
    } else {
      return null;
    }
  }

  /// List a repository&#39;s branches with HTTP info returned
  ///
  ///
  Future<Response> repoListBranchesWithHttpInfo(
      String owner, String repo) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/branches"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// List a repository&#39;s branches
  ///
  ///
  Future<List<Branch>> repoListBranches(String owner, String repo) async {
    Response response = await repoListBranchesWithHttpInfo(owner, repo);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return (apiClient.deserialize(_decodeBodyBytes(response), 'List<Branch>')
              as List)
          .map((item) => item as Branch)
          .toList();
    } else {
      return null;
    }
  }

  /// List a repository&#39;s collaborators with HTTP info returned
  ///
  ///
  Future<Response> repoListCollaboratorsWithHttpInfo(String owner, String repo,
      {int page, int limit}) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/collaborators"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    if (page != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "page", page));
    }
    if (limit != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "limit", limit));
    }

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// List a repository&#39;s collaborators
  ///
  ///
  Future<List<User>> repoListCollaborators(String owner, String repo,
      {int page, int limit}) async {
    Response response = await repoListCollaboratorsWithHttpInfo(owner, repo,
        page: page, limit: limit);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return (apiClient.deserialize(_decodeBodyBytes(response), 'List<User>')
              as List)
          .map((item) => item as User)
          .toList();
    } else {
      return null;
    }
  }

  /// List the Git hooks in a repository with HTTP info returned
  ///
  ///
  Future<Response> repoListGitHooksWithHttpInfo(
      String owner, String repo) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/hooks/git"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// List the Git hooks in a repository
  ///
  ///
  Future<List<GitHook>> repoListGitHooks(String owner, String repo) async {
    Response response = await repoListGitHooksWithHttpInfo(owner, repo);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return (apiClient.deserialize(_decodeBodyBytes(response), 'List<GitHook>')
              as List)
          .map((item) => item as GitHook)
          .toList();
    } else {
      return null;
    }
  }

  /// Get specified ref or filtered repository&#39;s refs with HTTP info returned
  ///
  ///
  Future<Response> repoListGitRefsWithHttpInfo(
      String owner, String repo, String ref) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (ref == null) {
      throw ApiException(400, "Missing required param: ref");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/git/refs/{ref}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "ref" + "}", ref.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Get specified ref or filtered repository&#39;s refs
  ///
  ///
  Future<List<Reference>> repoListGitRefs(
      String owner, String repo, String ref) async {
    Response response = await repoListGitRefsWithHttpInfo(owner, repo, ref);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return (apiClient.deserialize(
              _decodeBodyBytes(response), 'List<Reference>') as List)
          .map((item) => item as Reference)
          .toList();
    } else {
      return null;
    }
  }

  /// List the hooks in a repository with HTTP info returned
  ///
  ///
  Future<Response> repoListHooksWithHttpInfo(String owner, String repo,
      {int page, int limit}) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/hooks"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    if (page != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "page", page));
    }
    if (limit != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "limit", limit));
    }

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// List the hooks in a repository
  ///
  ///
  Future<List<Hook>> repoListHooks(String owner, String repo,
      {int page, int limit}) async {
    Response response =
        await repoListHooksWithHttpInfo(owner, repo, page: page, limit: limit);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return (apiClient.deserialize(_decodeBodyBytes(response), 'List<Hook>')
              as List)
          .map((item) => item as Hook)
          .toList();
    } else {
      return null;
    }
  }

  /// List a repository&#39;s keys with HTTP info returned
  ///
  ///
  Future<Response> repoListKeysWithHttpInfo(String owner, String repo,
      {int keyId, String fingerprint, int page, int limit}) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/keys"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    if (keyId != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "key_id", keyId));
    }
    if (fingerprint != null) {
      queryParams.addAll(_convertParametersForCollectionFormat(
          "", "fingerprint", fingerprint));
    }
    if (page != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "page", page));
    }
    if (limit != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "limit", limit));
    }

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// List a repository&#39;s keys
  ///
  ///
  Future<List<DeployKey>> repoListKeys(String owner, String repo,
      {int keyId, String fingerprint, int page, int limit}) async {
    Response response = await repoListKeysWithHttpInfo(owner, repo,
        keyId: keyId, fingerprint: fingerprint, page: page, limit: limit);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return (apiClient.deserialize(
              _decodeBodyBytes(response), 'List<DeployKey>') as List)
          .map((item) => item as DeployKey)
          .toList();
    } else {
      return null;
    }
  }

  /// List a repo&#39;s pull requests with HTTP info returned
  ///
  ///
  Future<Response> repoListPullRequestsWithHttpInfo(String owner, String repo,
      {String state,
      String sort,
      int milestone,
      List<int> labels,
      int page,
      int limit}) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/pulls"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    if (state != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "state", state));
    }
    if (sort != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "sort", sort));
    }
    if (milestone != null) {
      queryParams.addAll(
          _convertParametersForCollectionFormat("", "milestone", milestone));
    }
    if (labels != null) {
      queryParams.addAll(
          _convertParametersForCollectionFormat("multi", "labels", labels));
    }
    if (page != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "page", page));
    }
    if (limit != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "limit", limit));
    }

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// List a repo&#39;s pull requests
  ///
  ///
  Future<List<PullRequest>> repoListPullRequests(String owner, String repo,
      {String state,
      String sort,
      int milestone,
      List<int> labels,
      int page,
      int limit}) async {
    Response response = await repoListPullRequestsWithHttpInfo(owner, repo,
        state: state,
        sort: sort,
        milestone: milestone,
        labels: labels,
        page: page,
        limit: limit);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return (apiClient.deserialize(
              _decodeBodyBytes(response), 'List<PullRequest>') as List)
          .map((item) => item as PullRequest)
          .toList();
    } else {
      return null;
    }
  }

  /// List release&#39;s attachments with HTTP info returned
  ///
  ///
  Future<Response> repoListReleaseAttachmentsWithHttpInfo(
      String owner, String repo, int id) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (id == null) {
      throw ApiException(400, "Missing required param: id");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/releases/{id}/assets"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// List release&#39;s attachments
  ///
  ///
  Future<List<Attachment>> repoListReleaseAttachments(
      String owner, String repo, int id) async {
    Response response =
        await repoListReleaseAttachmentsWithHttpInfo(owner, repo, id);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return (apiClient.deserialize(
              _decodeBodyBytes(response), 'List<Attachment>') as List)
          .map((item) => item as Attachment)
          .toList();
    } else {
      return null;
    }
  }

  /// List a repo&#39;s releases with HTTP info returned
  ///
  ///
  Future<Response> repoListReleasesWithHttpInfo(String owner, String repo,
      {int perPage, int page, int limit}) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/releases"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    if (perPage != null) {
      queryParams.addAll(
          _convertParametersForCollectionFormat("", "per_page", perPage));
    }
    if (page != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "page", page));
    }
    if (limit != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "limit", limit));
    }

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// List a repo&#39;s releases
  ///
  ///
  Future<List<Release>> repoListReleases(String owner, String repo,
      {int perPage, int page, int limit}) async {
    Response response = await repoListReleasesWithHttpInfo(owner, repo,
        perPage: perPage, page: page, limit: limit);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return (apiClient.deserialize(_decodeBodyBytes(response), 'List<Release>')
              as List)
          .map((item) => item as Release)
          .toList();
    } else {
      return null;
    }
  }

  /// List a repo&#39;s stargazers with HTTP info returned
  ///
  ///
  Future<Response> repoListStargazersWithHttpInfo(String owner, String repo,
      {int page, int limit}) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/stargazers"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    if (page != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "page", page));
    }
    if (limit != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "limit", limit));
    }

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// List a repo&#39;s stargazers
  ///
  ///
  Future<List<User>> repoListStargazers(String owner, String repo,
      {int page, int limit}) async {
    Response response = await repoListStargazersWithHttpInfo(owner, repo,
        page: page, limit: limit);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return (apiClient.deserialize(_decodeBodyBytes(response), 'List<User>')
              as List)
          .map((item) => item as User)
          .toList();
    } else {
      return null;
    }
  }

  /// Get a commit&#39;s statuses with HTTP info returned
  ///
  ///
  Future<Response> repoListStatusesWithHttpInfo(
      String owner, String repo, String sha,
      {String sort, String state, int page, int limit}) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (sha == null) {
      throw ApiException(400, "Missing required param: sha");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/statuses/{sha}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "sha" + "}", sha.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    if (sort != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "sort", sort));
    }
    if (state != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "state", state));
    }
    if (page != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "page", page));
    }
    if (limit != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "limit", limit));
    }

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Get a commit&#39;s statuses
  ///
  ///
  Future<List<Status>> repoListStatuses(String owner, String repo, String sha,
      {String sort, String state, int page, int limit}) async {
    Response response = await repoListStatusesWithHttpInfo(owner, repo, sha,
        sort: sort, state: state, page: page, limit: limit);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return (apiClient.deserialize(_decodeBodyBytes(response), 'List<Status>')
              as List)
          .map((item) => item as Status)
          .toList();
    } else {
      return null;
    }
  }

  /// List a repo&#39;s watchers with HTTP info returned
  ///
  ///
  Future<Response> repoListSubscribersWithHttpInfo(String owner, String repo,
      {int page, int limit}) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/subscribers"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    if (page != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "page", page));
    }
    if (limit != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "limit", limit));
    }

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// List a repo&#39;s watchers
  ///
  ///
  Future<List<User>> repoListSubscribers(String owner, String repo,
      {int page, int limit}) async {
    Response response = await repoListSubscribersWithHttpInfo(owner, repo,
        page: page, limit: limit);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return (apiClient.deserialize(_decodeBodyBytes(response), 'List<User>')
              as List)
          .map((item) => item as User)
          .toList();
    } else {
      return null;
    }
  }

  /// List a repository&#39;s tags with HTTP info returned
  ///
  ///
  Future<Response> repoListTagsWithHttpInfo(String owner, String repo) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/tags"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// List a repository&#39;s tags
  ///
  ///
  Future<List<Tag>> repoListTags(String owner, String repo) async {
    Response response = await repoListTagsWithHttpInfo(owner, repo);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return (apiClient.deserialize(_decodeBodyBytes(response), 'List<Tag>')
              as List)
          .map((item) => item as Tag)
          .toList();
    } else {
      return null;
    }
  }

  /// Get list of topics that a repository has with HTTP info returned
  ///
  ///
  Future<Response> repoListTopicsWithHttpInfo(String owner, String repo,
      {int page, int limit}) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/topics"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    if (page != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "page", page));
    }
    if (limit != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "limit", limit));
    }

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Get list of topics that a repository has
  ///
  ///
  Future<TopicName> repoListTopics(String owner, String repo,
      {int page, int limit}) async {
    Response response =
        await repoListTopicsWithHttpInfo(owner, repo, page: page, limit: limit);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'TopicName')
          as TopicName;
    } else {
      return null;
    }
  }

  /// Merge a pull request with HTTP info returned
  ///
  ///
  Future repoMergePullRequestWithHttpInfo(String owner, String repo, int index,
      {MergePullRequestOption body}) async {
    Object postBody = body;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (index == null) {
      throw ApiException(400, "Missing required param: index");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/pulls/{index}/merge"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "index" + "}", index.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json", "text/plain"];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'POST', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Merge a pull request
  ///
  ///
  Future repoMergePullRequest(String owner, String repo, int index,
      {MergePullRequestOption body}) async {
    Response response =
        await repoMergePullRequestWithHttpInfo(owner, repo, index, body: body);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
    } else {
      return;
    }
  }

  /// Migrate a remote git repository with HTTP info returned
  ///
  ///
  Future<Response> repoMigrateWithHttpInfo({MigrateRepoForm body}) async {
    Object postBody = body;

    // verify required params are set

    // create path and map variables
    String path = "/repos/migrate".replaceAll("{format}", "json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json"];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'POST', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Migrate a remote git repository
  ///
  ///
  Future<Repository> repoMigrate({MigrateRepoForm body}) async {
    Response response = await repoMigrateWithHttpInfo(body: body);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Repository')
          as Repository;
    } else {
      return null;
    }
  }

  /// Sync a mirrored repository with HTTP info returned
  ///
  ///
  Future repoMirrorSyncWithHttpInfo(String owner, String repo) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/mirror-sync"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'POST', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Sync a mirrored repository
  ///
  ///
  Future repoMirrorSync(String owner, String repo) async {
    Response response = await repoMirrorSyncWithHttpInfo(owner, repo);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
    } else {
      return;
    }
  }

  /// Check if a pull request has been merged with HTTP info returned
  ///
  ///
  Future repoPullRequestIsMergedWithHttpInfo(
      String owner, String repo, int index) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (index == null) {
      throw ApiException(400, "Missing required param: index");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/pulls/{index}/merge"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "index" + "}", index.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Check if a pull request has been merged
  ///
  ///
  Future repoPullRequestIsMerged(String owner, String repo, int index) async {
    Response response =
        await repoPullRequestIsMergedWithHttpInfo(owner, repo, index);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
    } else {
      return;
    }
  }

  /// Search for repositories with HTTP info returned
  ///
  ///
  Future<Response> repoSearchWithHttpInfo(
      {String q,
      bool topic,
      bool includeDesc,
      int uid,
      int priorityOwnerId,
      int starredBy,
      bool private,
      bool template,
      String mode,
      bool exclusive,
      String sort,
      String order,
      int page,
      int limit}) async {
    Object postBody;

    // verify required params are set

    // create path and map variables
    String path = "/repos/search".replaceAll("{format}", "json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    if (q != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "q", q));
    }
    if (topic != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "topic", topic));
    }
    if (includeDesc != null) {
      queryParams.addAll(_convertParametersForCollectionFormat(
          "", "includeDesc", includeDesc));
    }
    if (uid != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "uid", uid));
    }
    if (priorityOwnerId != null) {
      queryParams.addAll(_convertParametersForCollectionFormat(
          "", "priority_owner_id", priorityOwnerId));
    }
    if (starredBy != null) {
      queryParams.addAll(
          _convertParametersForCollectionFormat("", "starredBy", starredBy));
    }
    if (private != null) {
      queryParams.addAll(
          _convertParametersForCollectionFormat("", "private", private));
    }
    if (template != null) {
      queryParams.addAll(
          _convertParametersForCollectionFormat("", "template", template));
    }
    if (mode != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "mode", mode));
    }
    if (exclusive != null) {
      queryParams.addAll(
          _convertParametersForCollectionFormat("", "exclusive", exclusive));
    }
    if (sort != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "sort", sort));
    }
    if (order != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "order", order));
    }
    if (page != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "page", page));
    }
    if (limit != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "limit", limit));
    }

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Search for repositories
  ///
  ///
  Future<SearchResults> repoSearch(
      {String q,
      bool topic,
      bool includeDesc,
      int uid,
      int priorityOwnerId,
      int starredBy,
      bool private,
      bool template,
      String mode,
      bool exclusive,
      String sort,
      String order,
      int page,
      int limit}) async {
    Response response = await repoSearchWithHttpInfo(
        q: q,
        topic: topic,
        includeDesc: includeDesc,
        uid: uid,
        priorityOwnerId: priorityOwnerId,
        starredBy: starredBy,
        private: private,
        template: template,
        mode: mode,
        exclusive: exclusive,
        sort: sort,
        order: order,
        page: page,
        limit: limit);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'SearchResults')
          as SearchResults;
    } else {
      return null;
    }
  }

  /// Get signing-key.gpg for given repository with HTTP info returned
  ///
  ///
  Future<Response> repoSigningKeyWithHttpInfo(String owner, String repo) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/signing-key.gpg"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Get signing-key.gpg for given repository
  ///
  ///
  Future<String> repoSigningKey(String owner, String repo) async {
    Response response = await repoSigningKeyWithHttpInfo(owner, repo);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'String')
          as String;
    } else {
      return null;
    }
  }

  /// Test a push webhook with HTTP info returned
  ///
  ///
  Future repoTestHookWithHttpInfo(String owner, String repo, int id) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (id == null) {
      throw ApiException(400, "Missing required param: id");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/hooks/{id}/tests"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'POST', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Test a push webhook
  ///
  ///
  Future repoTestHook(String owner, String repo, int id) async {
    Response response = await repoTestHookWithHttpInfo(owner, repo, id);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
    } else {
      return;
    }
  }

  /// List a repo&#39;s tracked times with HTTP info returned
  ///
  ///
  Future<Response> repoTrackedTimesWithHttpInfo(String owner, String repo,
      {String user,
      DateTime since,
      DateTime before,
      int page,
      int limit}) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/times"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    if (user != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "user", user));
    }
    if (since != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "since", since));
    }
    if (before != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "before", before));
    }
    if (page != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "page", page));
    }
    if (limit != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "limit", limit));
    }

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// List a repo&#39;s tracked times
  ///
  ///
  Future<List<TrackedTime>> repoTrackedTimes(String owner, String repo,
      {String user,
      DateTime since,
      DateTime before,
      int page,
      int limit}) async {
    Response response = await repoTrackedTimesWithHttpInfo(owner, repo,
        user: user, since: since, before: before, page: page, limit: limit);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return (apiClient.deserialize(
              _decodeBodyBytes(response), 'List<TrackedTime>') as List)
          .map((item) => item as TrackedTime)
          .toList();
    } else {
      return null;
    }
  }

  /// Transfer a repo ownership with HTTP info returned
  ///
  ///
  Future<Response> repoTransferWithHttpInfo(
      String owner, String repo, TransferRepoOption body) async {
    Object postBody = body;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (body == null) {
      throw ApiException(400, "Missing required param: body");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/transfer"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json", "text/plain"];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'POST', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Transfer a repo ownership
  ///
  ///
  Future<Repository> repoTransfer(
      String owner, String repo, TransferRepoOption body) async {
    Response response = await repoTransferWithHttpInfo(owner, repo, body);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Repository')
          as Repository;
    } else {
      return null;
    }
  }

  /// Update a file in a repository with HTTP info returned
  ///
  ///
  Future<Response> repoUpdateFileWithHttpInfo(String owner, String repo,
      String filepath, UpdateFileOptions body) async {
    Object postBody = body;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (filepath == null) {
      throw ApiException(400, "Missing required param: filepath");
    }
    if (body == null) {
      throw ApiException(400, "Missing required param: body");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/contents/{filepath}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "filepath" + "}", filepath.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json"];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'PUT', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Update a file in a repository
  ///
  ///
  Future<FileResponse> repoUpdateFile(String owner, String repo,
      String filepath, UpdateFileOptions body) async {
    Response response =
        await repoUpdateFileWithHttpInfo(owner, repo, filepath, body);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'FileResponse')
          as FileResponse;
    } else {
      return null;
    }
  }

  /// Replace list of topics for a repository with HTTP info returned
  ///
  ///
  Future repoUpdateTopicsWithHttpInfo(String owner, String repo,
      {RepoTopicOptions body}) async {
    Object postBody = body;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/topics"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = ["application/json", "text/plain"];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'PUT', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Replace list of topics for a repository
  ///
  ///
  Future repoUpdateTopics(String owner, String repo,
      {RepoTopicOptions body}) async {
    Response response =
        await repoUpdateTopicsWithHttpInfo(owner, repo, body: body);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
    } else {
      return;
    }
  }

  /// search topics via keyword with HTTP info returned
  ///
  ///
  Future<Response> topicSearchWithHttpInfo(String q,
      {int page, int limit}) async {
    Object postBody;

    // verify required params are set
    if (q == null) {
      throw ApiException(400, "Missing required param: q");
    }

    // create path and map variables
    String path = "/topics/search".replaceAll("{format}", "json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    queryParams.addAll(_convertParametersForCollectionFormat("", "q", q));
    if (page != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "page", page));
    }
    if (limit != null) {
      queryParams
          .addAll(_convertParametersForCollectionFormat("", "limit", limit));
    }

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// search topics via keyword
  ///
  ///
  Future<List<TopicResponse>> topicSearch(String q,
      {int page, int limit}) async {
    Response response =
        await topicSearchWithHttpInfo(q, page: page, limit: limit);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return (apiClient.deserialize(
              _decodeBodyBytes(response), 'List<TopicResponse>') as List)
          .map((item) => item as TopicResponse)
          .toList();
    } else {
      return null;
    }
  }

  /// Check if the current user is watching a repo with HTTP info returned
  ///
  ///
  Future<Response> userCurrentCheckSubscriptionWithHttpInfo(
      String owner, String repo) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/subscription"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Check if the current user is watching a repo
  ///
  ///
  Future<WatchInfo> userCurrentCheckSubscription(
      String owner, String repo) async {
    Response response =
        await userCurrentCheckSubscriptionWithHttpInfo(owner, repo);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'WatchInfo')
          as WatchInfo;
    } else {
      return null;
    }
  }

  /// Unwatch a repo with HTTP info returned
  ///
  ///
  Future userCurrentDeleteSubscriptionWithHttpInfo(
      String owner, String repo) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/subscription"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'DELETE', queryParams,
        postBody, headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Unwatch a repo
  ///
  ///
  Future userCurrentDeleteSubscription(String owner, String repo) async {
    Response response =
        await userCurrentDeleteSubscriptionWithHttpInfo(owner, repo);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
    } else {
      return;
    }
  }

  /// Watch a repo with HTTP info returned
  ///
  ///
  Future<Response> userCurrentPutSubscriptionWithHttpInfo(
      String owner, String repo) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/subscription"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'PUT', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// Watch a repo
  ///
  ///
  Future<WatchInfo> userCurrentPutSubscription(
      String owner, String repo) async {
    Response response =
        await userCurrentPutSubscriptionWithHttpInfo(owner, repo);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'WatchInfo')
          as WatchInfo;
    } else {
      return null;
    }
  }

  /// List a user&#39;s tracked times in a repo with HTTP info returned
  ///
  ///
  Future<Response> userTrackedTimesWithHttpInfo(
      String owner, String repo, String user) async {
    Object postBody;

    // verify required params are set
    if (owner == null) {
      throw ApiException(400, "Missing required param: owner");
    }
    if (repo == null) {
      throw ApiException(400, "Missing required param: repo");
    }
    if (user == null) {
      throw ApiException(400, "Missing required param: user");
    }

    // create path and map variables
    String path = "/repos/{owner}/{repo}/times/{user}"
        .replaceAll("{format}", "json")
        .replaceAll("{" + "owner" + "}", owner.toString())
        .replaceAll("{" + "repo" + "}", repo.toString())
        .replaceAll("{" + "user" + "}", user.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};

    List<String> contentTypes = [];

    String contentType =
        contentTypes.isNotEmpty ? contentTypes[0] : "application/json";
    List<String> authNames = [
      "AccessToken",
      "AuthorizationHeaderToken",
      "BasicAuth",
      "SudoHeader",
      "SudoParam",
      "Token"
    ];

    if (contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if (hasFields) {
        postBody = mp;
      }
    } else {}

    var response = await apiClient.invokeAPI(path, 'GET', queryParams, postBody,
        headerParams, formParams, contentType, authNames);
    return response;
  }

  /// List a user&#39;s tracked times in a repo
  ///
  ///
  Future<List<TrackedTime>> userTrackedTimes(
      String owner, String repo, String user) async {
    Response response = await userTrackedTimesWithHttpInfo(owner, repo, user);
    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if (response.body != null) {
      return (apiClient.deserialize(
              _decodeBodyBytes(response), 'List<TrackedTime>') as List)
          .map((item) => item as TrackedTime)
          .toList();
    } else {
      return null;
    }
  }
}
